@@ -1,4 +1,4 @@
-'''ofonod D-BUS mock template'''
+'''ofonod D-Bus mock template'''
 
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
